@@ -102,6 +102,7 @@ class Worker:
             if 'BlobName' in request_entity:
                 self._process_blob(request_id, request_entity, blob_func)
         except Exception as e:
+            self._record_request_failure(request_entity, e)
             if self.ltb_connection_string is not None:
                 self._record_failure(request_id, e)
             else:
@@ -193,6 +194,13 @@ class Worker:
         track = traceback.format_exc()
         function_failure_entity = {"PartitionKey": self.worker_name, "RowKey": request_id, "FailureMessage": str(e), "StackTrace": track}
         TableService(connection_string=self.ltb_connection_string).insert_entity(failure_table, function_failure_entity)
+
+    def _record_request_failure(self, request_entity, e: Exception):
+        trace = traceback.format_exc()
+        error_message = str(e)
+        request_entity['Error'] = error_message
+        request_entity['StackTrace'] = trace
+        self.table_client.update_entity(self.metadata_table_name, request_entity)
         
     def get_result(self, request_id):
         guid, request_hash = self._decode_id(request_id)
